==> haskell-persistent-sqlite-2.10.5-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.10.5
id: persistent-sqlite-2.10.5-FEUFo39dDwR3YlIQbGpGEE
key: persistent-sqlite-2.10.5-FEUFo39dDwR3YlIQbGpGEE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
abi: 2495052359f8f09ee3ef69c9ce2cebcc
exposed: True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.10.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.10.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-sqlite-2.10.5
hs-libraries: HSpersistent-sqlite-2.10.5-FEUFo39dDwR3YlIQbGpGEE
extra-libraries:
    pthread sqlite3
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-FcGmdT7SxdEGYrdumpBUzp
    containers-0.6.0.1 microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV
    monad-logger-0.3.31-7YU8gDZxquACgSGvZKbePy
    persistent-2.10.4-DDVyWa31Zqo5AKQBYOUbt7
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.10.5-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.10.5
id: persistent-sqlite-2.10.5-BjujCvhbim8EoKDVwJgTEk
key: persistent-sqlite-2.10.5-BjujCvhbim8EoKDVwJgTEk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
abi: b51e9054b229c9ecda8893f2d4a1293f
exposed: True
exposed-modules:
    Database.Persist.Sqlite Database.Sqlite Database.Sqlite.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.10.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-sqlite-2.10.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-sqlite-2.10.5
hs-libraries: HSpersistent-sqlite-2.10.5-BjujCvhbim8EoKDVwJgTEk
extra-libraries:
    pthread sqlite3
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL
    containers-0.6.0.1 microlens-th-0.4.3.2-BtNcM50Dy9m529DwUGkRbV
    monad-logger-0.3.31-7GuI6fn0wu46zyEORqvRSc
    persistent-2.10.4-EQlRAtVE7XNBeblki1cfTh
    resource-pool-0.2.3.2-gJbLOXkUsfHOTyD1xpnwB
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2 unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
